@@ -25,6 +25,7 @@
 #endif
 
 #include <dlog.h>
+#include "daemon_util.h"
 
 #define DEV_NULL "/dev/null"
 int daemonize (void) {
@@ -53,9 +54,9 @@ int daemonize (void) {
   return 0;
 }
 
-int resolve_uid(const char *setuid_user) {
+uid_t resolve_uid(const char *setuid_user) {
 #ifndef HAVE_WINDOWS
-  uid_t uid = 0;
+  int uid = 0;
   struct passwd *pw;
   if (!setuid_user) return 0;
 
@@ -65,10 +66,10 @@ int resolve_uid(const char *setuid_user) {
   else if(atoi(setuid_user)) /* numerical? */
     uid = atoi(setuid_user);
   else {
-    uid = -1;
+    uid = 0;
   }
-  if (uid < 0) {
-    dlog(DLOG_CRIT, "SYS: failed to lookup UID for user '%s'\n", setuid_user);
+  if (uid == 0) {
+    dlog(DLOG_CRIT, "SYS: invalid username '%s'\n", setuid_user);
   }
   return uid;
 #else
@@ -76,7 +77,7 @@ int resolve_uid(const char *setuid_user) {
 #endif
 }
 
-int resolve_gid(const char *setgid_group) {
+gid_t resolve_gid(const char *setgid_group) {
 #ifndef HAVE_WINDOWS
   gid_t gid = 0;
   struct group *gr;
@@ -87,10 +88,10 @@ int resolve_gid(const char *setgid_group) {
   else if(atoi(setgid_group)) /* numerical? */
     gid = atoi(setgid_group);
   else {
-    gid = -1;
+    gid = 0;
   }
-  if (gid < 0) {
-    dlog(DLOG_CRIT, "SYS: failed to lookup GID for group '%s'\n", setgid_group);
+  if (gid == 0) {
+    dlog(DLOG_CRIT, "SYS: invalid group '%s'\n", setgid_group);
   }
   return gid;
 #else
@@ -99,7 +100,7 @@ int resolve_gid(const char *setgid_group) {
 }
 
 /* set process user and group(s) id */
-int drop_privileges(const int uid, const int gid) {
+int drop_privileges(const uid_t uid, const gid_t gid) {
 #ifndef HAVE_WINDOWS
   if (getuid()) {
     dlog(DLOG_WARNING, "SYS: non-suid. Keeping current privileges.\n");
