@@ -24,6 +24,7 @@
 #include <math.h>
 #include <sys/stat.h>
 #include <libgen.h> // basename
+#include <locale.h>
 
 #include "daemon_log.h"
 #include "daemon_util.h"
@@ -347,6 +348,11 @@ int main (int argc, char **argv) {
     if (do_chroot(cfg_chroot)) {exitstatus = -1; goto errexit;}
   }
 
+#ifdef HAVE_WINDOWS
+  if (strlen (docroot) == 0) {
+    dlog(DLOG_INFO, "No document-root, allowing all drive-letters\n");
+  } else
+#endif
   if (stat(docroot, &sb) || !S_ISDIR(sb.st_mode)) {
     dlog(DLOG_CRIT, "document-root is not a directory\n");
     exitstatus = -1;
@@ -375,6 +381,12 @@ int main (int argc, char **argv) {
 #endif
   }
 
+  char const* const current_c_locale = setlocale (LC_NUMERIC, 0);
+  if (strcmp ("C", current_c_locale) != 0) {
+    dlog(DLOG_INFO, "Setting locate to 'C' for portable numerics.\n");
+    setlocale (LC_NUMERIC, "C");
+  }
+
   /* all systems go */
 
   dlog(DLOG_INFO, "Initialization complete. Starting server.\n");
