@@ -7,7 +7,7 @@
 
 #define HTMLBODYPERC(P) \
   "<body style=\"width:900px; margin:110px auto 0 auto;\">" \
-  "<div style=\"position:fixed; height:100px; width:100%"P"; top:0; left:0; background:#000; text-align:center;\"><a href=\"/\"><img alt=\"Harvid\" src=\"/logo.jpg\"/></a></div>\n"
+  "<div style=\"position:fixed; height:100px; width:100%"P"; top:0; left:0; background:#000; text-align:center;\"><a href=\"/\"><img alt=\"Harvid\" src=\"/logo.jpg\" style=\"border:0px;\"/></a></div>\n"
 
 #define HTMLBODY HTMLBODYPERC("%")
 
